@@ -37,7 +37,7 @@
 
 struct Combi
 {
-    typedef int value_type;
+    using value_type = int;
 };
 
 bool operator<(Combi const &lhs, Combi const &rhs);
