@@ -39,7 +39,7 @@ concept ConstDereferenceable =
 
 struct InIt
 {
-    typedef int value_type;
+    using value_type = int;
 
     InIt &operator++();
     InIt operator++(int);
@@ -101,7 +101,7 @@ void fwdFun(Type tp)
 //iterable
 struct Iterable
 {
-    typedef int value_type;
+    using value_type = int;
 
     Iterable &operator++();
     Iterable operator++(int);
