@@ -2,7 +2,7 @@
 #include <vector>
 
 template <typename Type>
-concept bool Addable =
+concept Addable =
     requires(Type lh, Type rh)
     {
         lh + rh;
