@@ -80,5 +80,7 @@ int main()
 
     VI e = a + b  + c + d;
 
-    cout << "# index computations: " << VI::s_count << '\n';
+// 2nd cout avoids the 'not used' compiler warning
+//    cout << "# index computations: " << VI::s_count << '\n';
+    cout << "# index computations: " << e.s_count << '\n';
 }
