@@ -25,7 +25,7 @@ int main()
                                        Policy<string>{ "world" } };
 
 
-     typedef Multi<Policy, string, int> MPSI;
+     using MPSI = Multi<Policy, string, int>;
      MPSI mpsi{ string{ "hello" }, 4 };
 //=
 
@@ -45,7 +45,7 @@ int main()
 //=
 
 //SIX
-    typedef Multi<Policy, int, int> MPII;
+    using MPII = Multi<Policy, int, int>;
     MPII mpii{ 4, 18 };
 
     cout << get<0>(mpii).d_type << ' ' << get<1>(mpii).d_type << '\n';
@@ -55,7 +55,7 @@ int main()
     cout << get<0>(mpii).d_type << ' ' << get<1>(mpii).d_type << '\n';
 
 //SEVEN
-    typedef Multi<Vector, int, double> MVID;
+    using MVID = Multi<Vector, int, double>;
     MVID mi{ {1, 2, 3}, {1.2, 3.4, 5.6, 7.8} };
 //=
 
