@@ -4,7 +4,7 @@
 template <typename TemplateType>
 struct TypeType
 {
-    typedef TemplateType Type;
+    using Type = TemplateType;
 };
 
 #endif
