@@ -18,6 +18,6 @@ int main()
 
     cout <<
         accumulate(values.begin(), values.end(), 0, lambda) << '\n' <<
-        accumulate(text.begin(), text.end(), string(), lambda) << '\n';
+        accumulate(text.begin(), text.end(), string{}, lambda) << '\n';
 }
 //=
