@@ -5,6 +5,7 @@
 #include <istream>
 #include <sstream>
 #include <fstream>
+#include <memory>
 
 /*
     fis >> field(3) >> x    extracts x over max 3 positions.
@@ -24,17 +25,17 @@ namespace FBB
     class field;
 
 //INITIAL
-    class fistream: public std::istream
+    class Fistream: public std::istream
     {
-        std::auto_ptr<std::filebuf> d_filebuf;
+        std::unique_ptr<std::filebuf> d_filebuf;
         std::streambuf *d_streambuf;
         std::istringstream d_iss;
         size_t d_width;
 //=
         public:
 //CONS
-            fistream(std::istream &stream);
-            fistream(char const *name,
+            Fistream(std::istream &stream);
+            Fistream(char const *name,
                 std::ios::openmode mode = std::ios::in);
 //=
             std::istream &setField(field const &params);
@@ -44,7 +45,7 @@ namespace FBB
 //FIELD
     class field
     {
-        friend class fistream;
+        friend class Fistream;
         size_t d_width;
         bool     d_newWidth;
 
