@@ -7,7 +7,7 @@
     template <typename Type>
     class Vector2: public std::vector<std::vector<Type> >
     {
-        typedef typename Vector2<Type>::iterator iterator;
+        using iterator = typename Vector2<Type>::iterator;
 
         template <typename Iterator, typename Class, typename Data>
         friend Class &ForEach(Iterator begin, Iterator end, Class &object,
