@@ -1,6 +1,8 @@
     #include "child.h"
     #include <iostream>
     #include <string>
+    #include <cstdlib>
+
     using namespace std;
 
 //CHILD
@@ -37,13 +39,13 @@
                     string  line;
                     getline(cin, line);
                     cout << "Child " << d_nr << ":" << ++message << ": " <<
-                                                        line << endl;
+                                                        line << '\n';
                 }
             }
             catch (...)
             {
                     cout << "Child " << d_nr << ":" << ++message << ": " <<
-                                "select() failed" << endl;
+                                "select() failed" << '\n';
             }
         }
         exit(0);
