@@ -9,10 +9,10 @@
     {
         Pipe    d_pipe;
 
-        virtual void childRedirections();
-        virtual void parentRedirections();
-        virtual void childProcess();
-        virtual void parentProcess();
+        void childRedirections() override;
+        void parentRedirections() override;
+        void childProcess() override;
+        void parentProcess() override;
     };
 //=
 
