@@ -27,7 +27,7 @@
         };
         cout << "pairs constructed\n";
 
-        map<string, MyClass> mapsm{ &pairs[0], &pairs[1];
+        map<string, MyClass> mapsm{ &pairs[0], &pairs[1] };
         cout << "mapsm constructed\n";
     }
     /*
@@ -37,8 +37,6 @@
     MyClass destructor
     pairs constructed
     MyClass copy constructor
-    MyClass copy constructor
-    MyClass destructor
     mapsm constructed
     MyClass destructor
     MyClass destructor
