@@ -7,7 +7,7 @@ class Recursive
 {
     class State: public PromiseBase<Recursive, State>
     {
-        typedef std::coroutine_handle<State> Handle;
+        using Handle = std::coroutine_handle<State>;
 
         size_t d_level;
         size_t d_value;
@@ -21,13 +21,13 @@ class Recursive
     };
 
     public:
-        typedef std::coroutine_handle<State> Handle;
+        using Handle = std::coroutine_handle<State>;
 
     private:
         Handle d_handle;
 
     public:
-        typedef State promise_type;
+        using promise_type = State;
 
 //iter
     class Iterator
