@@ -7,7 +7,7 @@
 //hdr
 class Dir
 {
-    typedef dirent DirEntry;
+    using DirEntry = dirent;
 
     DIR *d_dirPtr = 0;
     Dir *d_recursive = 0;
