@@ -13,8 +13,8 @@ class Done: public Awaiter
     static size_t s_count;
 
     public:
-        typedef State promise_type;
-        typedef std::coroutine_handle<State> Handle;
+        using promise_type = State;
+        using Handle = std::coroutine_handle<State>;
 
         explicit Done(Handle handle);
         ~Done();
