@@ -6,7 +6,7 @@
 //class
 class Awaiter
 {
-    typedef std::coroutine_handle<> Handle;
+    using Handle = std::coroutine_handle<>;
 
     Handle d_handle;
 
