@@ -14,8 +14,8 @@ class Start
     std::coroutine_handle<State> d_handle;
 
     public:
-        typedef State promise_type;
-        typedef std::coroutine_handle<State> Handle;
+        using promise_type = State;
+        using Handle = std::coroutine_handle<State>;
 
         explicit Start(Handle handle);
         ~Start();
