@@ -11,7 +11,7 @@
 
 struct Reader
 {
-    typedef std::optional<float> ValueType;
+    using ValueType = std::optional<float>;
 
     private:
         class State: public PromiseBase<Reader, State>
@@ -27,7 +27,7 @@ struct Reader
         std::coroutine_handle<State> d_handle;
 
     public:
-        typedef State promise_type;
+        using promise_type = State;
 
         explicit Reader(std::coroutine_handle<State> handle);
         ~Reader();
