@@ -16,11 +16,11 @@ class Recursive
     };
 
     private:
-        typedef std::coroutine_handle<State> Handle;
+        using Handle = std::coroutine_handle<State>;
         Handle d_handle;
 
     public:
-        typedef State promise_type;
+        using promise_type = State;
 
         explicit Recursive(Handle handle);
         ~Recursive();
