@@ -6,7 +6,7 @@
 
 struct Fibo
 {
-   typedef std::tuple<size_t, size_t, size_t> Triplet;
+   using Triplet = std::tuple<size_t, size_t, size_t>;
 
     private:
         class State: public PromiseBase<Fibo, State>
@@ -18,11 +18,11 @@ struct Fibo
                 size_t value() const;
         };
 
-        typedef std::coroutine_handle<State> Handle;
+        using Handle = std::coroutine_handle<State>;
         Handle d_handle;
 
     public:
-        typedef State promise_type;
+        using promise_type = State;
 
         explicit Fibo(std::coroutine_handle<State> handle);
         ~Fibo();
