@@ -4,15 +4,11 @@
     #include <iostream>
     using namespace std;
 
-    class CaseString
+    bool caseString(string const &first, string const &second)
     {
-        public:
-            bool operator()(string const &first,
-                            string const &second) const
-            {
-                return !strcasecmp(first.c_str(), second.c_str());
-            }
-    };
+        return strcasecmp(first.c_str(), second.c_str()) == 0;
+    }
+
     int main()
     {
         string first[] =
@@ -25,19 +21,17 @@
                 "alpha", "bravo", "charley", "delta", "echo",
                 "foxtrot", "golf", "hotel"
             };
-        string *last = first + sizeof(first) / sizeof(string);
+        auto past = end(first);
 
         cout << "The elements of `first' and `second' are pairwise " <<
-            (equal(first, last, second) ? "equal" : "not equal") <<
+            (equal(first, past, second) ? "equal" : "not equal") <<
             '\n' <<
             "compared case-insensitively, they are " <<
             (
-                equal(first, last, second, CaseString{}) ?
+                equal(first, past, second, caseString) ?
                     "equal" : "not equal"
             ) << '\n';
     }
-    /*
-        Displays:
-            The elements of `first' and `second' are pairwise not equal
-            compared case-insensitively, they are equal
-    */
+    //  Displays:
+    //      The elements of `first' and `second' are pairwise not equal
+    //      compared case-insensitively, they are equal
