@@ -5,31 +5,22 @@
     #include <utility>
     using namespace std;
 
-    class CaseString
+    bool caseString(string const &first, string const &second)
     {
-        public:
-            bool operator()(string const &first, string const &second) const
-            {
-                return strcasecmp(first.c_str(), second.c_str()) == 0;
-            }
-    };
+        return strcasecmp(first.c_str(), second.c_str()) == 0;
+    }
+
     int main()
     {
-        string range1[] =
-            {
-                "alpha", "bravo", "foxtrot", "hotel", "zulu"
-            };
-        string range2[] =
-            {
-                "alpha", "bravo", "foxtrot", "Hotel", "zulu"
-            };
+        string range1[] = { "alpha", "bravo", "foxtrot", "hotel", "zulu" };
+        string range2[] = { "alpha", "bravo", "foxtrot", "Hotel", "zulu" };
         pair<string *, string *> pss = mismatch(range1, range1 + 5, range2);
 
         cout << "The elements " << *pss.first << " and " << *pss.second <<
-                " at offset " << (pss.first - range1) << " differ\n";
+                " differ at index " << (pss.first - range1) << '\n';
         if
         (
-            mismatch(range1, range1 + 5, range2, CaseString{}).first
+            mismatch(range1, range1 + 5, range2, caseString).first
             ==
             range1 + 5
         )
