@@ -20,10 +20,8 @@
         copy(ia, ia + 10, ostream_iterator<int>(cout, " "));
         cout << '\n';
     }
-    /*
-        Displays:
-            sorting with respect to 4
-            1 2 3 4 9 7 5 6 8 10
-            sorting with respect to 5
-            10 8 7 9 6 5 3 4 2 1
-    */
+    //  Displays:
+    //      sorting with respect to 4
+    //      1 2 3 4 9 7 5 6 8 10
+    //      sorting with respect to 5
+    //      10 8 7 9 6 5 3 4 2 1
