@@ -15,8 +15,7 @@
         copy
         (
             remaining,
-            replace_copy(words, words + size, remaining, string("alpha"),
-                                                         string("ALPHA")),
+            replace_copy(words, words + size, remaining, "alpha"s, "ALPHA"s),
             ostream_iterator<string>(cout, " ")
         );
         cout << '\n';
