@@ -30,8 +30,6 @@
             ostream_iterator<string>(cout, " "));
         cout << '\n';
     }
-    /*
-        Displays:
-            kilo lima mike november oscar romeo
-            kilo lima mike november oscar ROMEO
-    */
+    //  Displays:
+    //      kilo lima mike november oscar romeo
+    //      kilo lima mike november oscar ROMEO
