@@ -10,10 +10,14 @@
     {
         return strcasecmp(left.c_str(), right.c_str()) < 0;
     }
+
     int main()
     {
-        string set1[] = { "kilo", "lima", "mike", "november",
-                          "oscar", "papa", "quebec" };
+        string set1[] =
+            {
+                "kilo", "lima", "mike", "november",
+                "oscar", "papa", "quebec"
+            };
         string set2[] = { "papa", "quebec", "romeo"};
         string result[8];
 
@@ -36,9 +40,7 @@
                    ostream_iterator<int>(cout, " "));
         cout << '\n';
     }
-    /*
-        Displays:
-            kilo lima mike november oscar papa quebec romeo
-            kilo lima mike november oscar papa quebec ROMEO
-            1 2 3 3 3 4 5 5 5 6 7
-    */
+    //  Displays:
+    //      kilo lima mike november oscar papa quebec romeo
+    //      kilo lima mike november oscar papa quebec ROMEO
+    //      1 2 3 3 3 4 5 5 5 6 7
