@@ -24,7 +24,7 @@ class FC
     friend ostream &operator<<(ostream &out, In const &in);
 
     using time_t2tm = tm (*)(const time_t *);
-    using TPfileClock =  time_point<__file_clock>;
+    using TPfileClock =  time_point<file_clock>;
     using TPsystemClock = time_point<system_clock>;
 
     static TPsystemClock const s_sPoint;
@@ -36,13 +36,13 @@ class FC
             LT,
             GMT
         };
-                    // system time point corresponding to __file_clock
+                    // system time point corresponding to file_clock
         static TPsystemClock sysTimePoint(TPfileClock const &fp);
 
-                    // tm corresponding to __file_clock for local time
+                    // tm corresponding to file_clock for local time
         static tm tmLocal(TPfileClock const &ftp);
 
-                    // tm corresponding to __file_clock for gmtime
+                    // tm corresponding to file_clock for gmtime
         static tm tmGMT(TPfileClock const &ftp);
 
         static In put_time(TPfileClock const &fp, char const *fmt = "%c",
@@ -56,7 +56,7 @@ FC::TPsystemClock const FC::s_sPoint = system_clock::now();
 
                                         // 'now' expressed for file_clock
 int const FC::s_offset = FC::s_sPoint.time_since_epoch().count() -
-                         __file_clock::now().time_since_epoch().count();
+                         file_clock::now().time_since_epoch().count();
 
 FC::In::In(tm const &tmData, char const *fmt)
 :
@@ -110,10 +110,10 @@ tm FC::to_tm(tm *(*funPtr)(const time_t *), TPfileClock const &fp)
     return *(*funPtr)(&secs);
 }
 
-time_point<system_clock> conv1(time_point<__file_clock> const &point)
+time_point<system_clock> conv1(time_point<file_clock> const &point)
 {
     auto systemNow = system_clock::now().time_since_epoch();
-    auto fileNow = __file_clock::now().time_since_epoch();
+    auto fileNow = file_clock::now().time_since_epoch();
 
     return time_point<system_clock>{
                 nanoseconds(point.time_since_epoch() +
@@ -134,7 +134,7 @@ int main()
 
 
                                         // 'now' expressed for file_clock
-    time_point<__file_clock> fPoint = __file_clock::now();
+    time_point<file_clock> fPoint = file_clock::now();
     int fnow = fPoint.time_since_epoch().count();
 
     cout << "file clock now in seconds since the (fc) epoch: " << fnow <<
