@@ -12,7 +12,9 @@ int main()
     // steady_clock::to_sys(steady_clock::now());   // not for steady_clock
     // high_resolution_clock::to_sys(               // not for high_res._clock
     //              high_resolution_clock::now());
-    __file_clock::to_sys(__file_clock::now());
-    //__file_clock::to_time_t(__file_clock::now()); // not in __file_clock
+
+    file_clock::to_sys(file_clock::now());
+
+    //file_clock::to_time_t(file_clock::now());     // not in file_clock
     // steady_clock::to_time_t(steady_clock::now());// not in steady_clock
 }
