@@ -4,8 +4,6 @@
 
 #include <bobcat/exception>
 
-#include "clocktimeconv"
-
 using namespace std;
 using namespace chrono;
 using namespace filesystem;
@@ -25,10 +23,16 @@ try
                                                            )
                             );
 
+    auto syspoint = system_clock::now();
+    auto filepoint = clock_time_conversion<file_clock, system_clock>
+                                                            (syspoint);
+//    cout << syspoint.count() << '\n' <<
+//            filepoint.count() << '\n';
+return 0;
 
     cout << put_time(localtime(&seconds), "%c") << '\n';
 
-    auto sysTime = __file_clock::to_sys(__file_clock::now());
+    auto sysTime = file_clock::to_sys(file_clock::now());
 
     time_t sysSecs = system_clock::to_time_t(sysTime);
 
@@ -36,8 +40,8 @@ try
 
 
 //    seconds = system_clock::to_time_t(
-//        clock_time_conversion<system_clock, __file_clock>{}(
-//                                                    __file_clock::now()
+//        clock_time_conversion<system_clock, file_clock>{}(
+//                                                    file_clock::now()
 //                                                           )
 //                            );
 //
