@@ -1,6 +1,6 @@
     Binary operator+(Binary const &lhs, Binary const &rhs)
     {
-        Binary tmp(lhs);
+        Binary tmp{ lhs };
         tmp.add(rhs);
         return tmp;
     }
