@@ -15,7 +15,7 @@ void Base::pureimp()
 class Derived: public Base
 {
     public:
-        virtual void pureimp();
+        void pureimp() override;
 };
 inline void Derived::pureimp()
 {
