@@ -66,9 +66,9 @@ class Derived1: public Clonable::Base
         {}
         Derived1(Derived1 const &other)
         {}
-        ~Derived1()
+        ~Derived1() override
         {}
-        virtual Clonable::Base *clone() const
+        Clonable::Base *clone() const override
         {
             return new Derived1(*this);
         }
