@@ -64,9 +64,9 @@
     class Derived1: public Base
     {
         public:
-            ~Derived1();
+            ~Derived1() override;
         private:
-            virtual Base *newCopy() const;
+            Base *newCopy() const override;
     };
     inline Base *Derived1::newCopy() const
     {
