@@ -12,11 +12,6 @@
 
         for (int idx = 0; idx < 6; ++idx)
             cout << iArr[idx] << ", ";
-
-        cout << endl;
+        cout << '\n';
     }
-    /*
-        Generated output:
-
-        -1, 2, -3, 4, -5, 6,
-    */
+    // Displays:  -1, 2, -3, 4, -5, 6,
