@@ -5,7 +5,7 @@
 
     int main()
     {
-        shared_ptr<string> sp(new string("Hello world"));
+        shared_ptr<string> sp(new string{ "Hello world" });
         shared_ptr<string> sp2(sp);
 
         sp->insert(strlen("Hello "), "C++ ");
