@@ -2,5 +2,5 @@
 
 for x in `cat files.in`
 do
-    g++ --std=c++11 -c $x
+    g++ -c $x
 done
