@@ -3,5 +3,5 @@
 void workforce()
 {
     for (size_t idx = 0; idx != g_sizeofWorkforce; ++idx)
-        thread(worker).detach();
+        g_thread.push_back(thread{ worker });   // create the worker threads
 }
