@@ -11,9 +11,9 @@ void compute(promise<int> &ref)
 
 int main()
 {
-    std::promise<int> p;
-    std::thread(compute, ref(p)).detach();
+    std::promise<int> prom;
+    std::thread(compute, ref(prom)).detach();
 
-    cout << p.get_future().get() << '\n';
+    cout << prom.get_future().get() << '\n';
 }
 //=
